summaryrefslogtreecommitdiff
path: root/deps/npm/lib/help.js
diff options
context:
space:
mode:
Diffstat (limited to 'deps/npm/lib/help.js')
-rw-r--r--deps/npm/lib/help.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/deps/npm/lib/help.js b/deps/npm/lib/help.js
index cfac917999..9763d5fccd 100644
--- a/deps/npm/lib/help.js
+++ b/deps/npm/lib/help.js
@@ -38,7 +38,7 @@ function help (args, cb) {
return npmUsage(valid, cb)
}
- // npm <cmd> -h: show command usage
+ // npm <command> -h: show command usage
if (npm.config.get('usage') &&
npm.commands[section] &&
npm.commands[section].usage) {
@@ -169,7 +169,7 @@ function npmUsage (valid, cb) {
npm.config.get('long') ? usages()
: ' ' + wrap(commands),
'',
- 'npm <cmd> -h quick help on <cmd>',
+ 'npm <command> -h quick help on <command>',
'npm -l display full usage info',
'npm help <term> search for help on <term>',
'npm help npm involved overview',
@@ -185,7 +185,7 @@ function npmUsage (valid, cb) {
}
function usages () {
// return a string of <cmd>: <usage>
var maxLen = 0
return Object.keys(npm.commands).filter(function (c) {
return c === npm.deref(c)
@@ -185,7 +185,7 @@ function npmUsage (valid, cb) {
}
function usages () {
- // return a string of <cmd>: <usage>
+ // return a string of <command>: <usage>
var maxLen = 0
return Object.keys(npm.commands).filter(function (c) {